@@ -12,7 +12,7 @@ RE_IP = re.compile(
     r'(?P<host>\S+) \((?P<ip>\d+\.\d+\.\d+\.\d+)\)'
 )
 RE_STATUS = re.compile(
-    r'(?P<port>\d+)/\S+\s+(?P<state>\S+)\s+\S+\s+\((?P<version>[^)]+)\)')
+    r'(?P<port>\d+)/\S+\s+(?P<state>\S+)\s+\S+\s+(?P<version>.*)$')
 
 RE_KEY = re.compile(
     r'\|(?:\s+|_)(?:ssh-hostkey:\s+)?(?P<size>\d+)\s+(?P<fingerprint>(?:\w\w\:)+\w\w)'
@@ -106,9 +106,11 @@ def main():
     import argparse
     parser = argparse.ArgumentParser()
     parser.add_argument('--port', '-p', type=int, default=22)
-    parser.add_argument('--db-user', nargs='?', help='postgres username',
+    parser.add_argument('--db-user', nargs='?', 
+        help='postgres username (default sshscanner)',
         default='sshscanner')
-    parser.add_argument('--db-pass', nargs='?', help='postgres password',
+    parser.add_argument('--db-pass', nargs='?',
+        help='postgres password (default ssh)',
         default='ssh')
     parser.add_argument('--skip-db', '-s', action='store_true',
         help='skip saving to postgresql database')
